@@ -31,13 +31,14 @@ rprofile_d <- function(sibling = FALSE, all = FALSE, check = NA,
     if (is.null(paths)) paths <- find_rprofile_d(sibling = sibling, all = all)
     files <- list_d_files(paths, filter = filter_files)
     encoding <- getOption("encoding")
+    keep_source <- getOption("keep.source", TRUE)
     
     source_print_eval <- function(pathname) {
       current_script_pathname(pathname)
       on.exit(current_script_pathname(NA_character_))
       source(pathname, encoding = encoding, local = FALSE, chdir = FALSE,
              print.eval = TRUE,
-             keep.source = FALSE, echo = FALSE, verbose = FALSE)
+             keep.source = keep_source, echo = FALSE, verbose = FALSE)
     }
     
     files_apply(files, fun = source_print_eval,
